@@ -88,7 +88,7 @@ class log_in:
             file = open("userDetails.txt")
             users = file.read().strip().split()
             username = input("Please enter your username: ")
-            password = input("Please enter %s's Password:" % username)
+            password = getpass.getpass("Please enter %s's Password:" % username)
             #while True:
             if username in users:
                 if password in users:
@@ -119,10 +119,8 @@ class logged_in:
     chatroom = None
     clientPusher = None
     user = None
-    #self.user = log_in.__init__()
-    #user = None
-    chatrooms = ["sports", "general", "education", "health", "technology"]
-    #chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
+    chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
+    
     def __init__(self):
         print("\n")        
         print(colored("You're logged in   ", "blue"))
